==> haskell-interpolatedstring-perl6-1.0.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.1
id: interpolatedstring-perl6-1.0.1-59aSbzRjzN5921RtwAM3CF
key: interpolatedstring-perl6-1.0.1-59aSbzRjzN5921RtwAM3CF
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 9a63c1432c8a6f6b2489635cefa72e2c
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.6.1/site-local/interpolatedstring-perl6-1.0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/interpolatedstring-perl6-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.1-59aSbzRjzN5921RtwAM3CF
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.0.3-Gx2Aimm4ZaBIxQrAmGHilY
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.1
id: interpolatedstring-perl6-1.0.1-JTbKVmJ6mf0EN7nfH1AgFE
key: interpolatedstring-perl6-1.0.1-JTbKVmJ6mf0EN7nfH1AgFE
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 8b240c5c697acd9785ed0762e9c6f0e6
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.6.2/site-local/interpolatedstring-perl6-1.0.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/interpolatedstring-perl6-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.1-JTbKVmJ6mf0EN7nfH1AgFE
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.0.3-7AGpnmqhJ3o3VgekKMC4vq
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
